@@ -15,7 +15,7 @@ from http_tools import AbmServiceConnector
 class DetectorHttpConnector:
     @dataclass(kw_only=True)
     class Config(AbmServiceConnector.Config):
-        server_name: str
+        project_name: str
 
     Context = AbmServiceConnector.Context
 
